# Gym

This agent trains an RL algorithm using OpenAI Gym.

## Description

This agent is part of the Fetch.ai Gym demo. It uses its primary skill, the `fetchai/gym` skill, to train a reinforcement learning (RL) algorithm using OpenAI Gym. 

It demonstrate how an RL agent can be wrapped inside a skill by decoupling the RL agent from the gym environment, allowing them to run in separate execution environments.

## Links

* <a href="https://docs.fetch.ai/aea/gym-skill/" target="_blank">Gym Demo</a>
* <a href="https://docs.fetch.ai/aea/gym-example/" target="_blank">Gym Example</a>
* <a href="https://gym.openai.com" target="_blank">OpenAI Gym</a>